@@ -6,7 +6,7 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub libs
 {
@@ -14,13 +14,6 @@ sub libs
   
   my $libs = $class->SUPER::libs(@_);
 
-  if($class->install_type eq 'share'
-  && !$class->config('finished_installing'))
-  {
-    my $working_dir = $class->config('working_directory');
-    $libs = "-L$working_dir/.libs -lffi";
-  }
-  
   if($^O eq 'openbsd' && !$Config{usethreads} && Alien::FFI->install_type eq 'share')
   {
     $libs .= ' /usr/lib/libpthread.a';
@@ -41,13 +34,6 @@ sub cflags
   
   my $cflags = $class->SUPER::cflags(@_);
   
-  if($class->install_type eq 'share'
-  && !$class->config('finished_installing'))
-  {
-    my $working_dir = $class->config('working_directory');
-    $cflags = "-I$working_dir/include";
-  }
-
   if($class->install_type eq 'share'
   && $^O eq 'MSWin32'
   && $Config{ccname} eq 'cl')
@@ -73,7 +59,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
